## cbthelper (for python)
cbthelper wraps CrossBrowserTesting's [selenium api](https://crossbrowsertesting.com/apidocs/v3/selenium.html) into an easy to use library.

#### Install
```
pip install cbthelper
```

#### Usage
You can find an example of how to use the library in the example directory. Don't forget to set username and authkey in example/main.py. You can also set the environment variables CBT\_USERNAME and CBT\_AUTHKEY.

[Grab the documentation here](https://cbthelper.readthedocs.io/en/latest/)
